Changelog
=========

0.5.4 (2020-08-31)
------------------
- Added codacy configuration
- Fixed some code style issues
- Added codebase for testing and coverage
- Added configurable navigation
- Fixed html head meta
- Added visual improvements


0.5.3 (2020-08-04)
------------------
- Fixed project initialization
- Refactored template loader

0.5.2 (2020-08-03)
------------------
- Added conftest.py to import pytest fixture
- Added tests and fixtures

0.5.0 (2020-07-25)
------------------
- Added minified css file static file to build
- Fixed missing init import
- Added csscompressor to deps
- Added n bits hash for strings
- Added static file compilation
- Removed NodeJS and yarn dependencies


0.3.0 (2020-02-22)
------------------
- Upgrade project version to 0.3.0.
- Improve CLI readability.
- Add Win32 support for yarn.
- Add function to check if running Linux.


0.2.1 (2019-11-10)
------------------
- Remove Travis cached directory dist/
- Release version 0.2.1.
- Cache dist directory in Travis CI.
- Fix Travis CI file.
- Fix Travis Ci file.
- Add jobs to Travis pipeline.
- Fix Travis job.
- Remove Twine test upload for master branch.
- Fix Travis job for Twine upload.
- Add Twine upload job.
- Prepare for 0.2.0 version release.


0.0.1 (2019-11-03)
------------------
- Minor design changes
- Catch exception when yarn is not install
- Include main requirements file
- Update pre-compiled assets
- Minor layout changes
- Minor design changes
- Add custom variables to templates
- Fix requirements not read from text file
- Remove quote
- Update README.md
- Update and rename eslintrc.js to .eslintrc
- Add ESLint conf file
- Update README.md
- Update .travis.yml
- Create requirements-test.txt
- Update requirements.txt
- Update setup.py
- Update README.md
- Update README.md
- Create .travis.yml
- Update README.md
- Minor design changes
- Catch exception when yarn is not install
- Include main requirements file
- Update pre-compiled assets
- Minor layout changes
- Minor design changes
- Add custom variables to templates.
- Fix requirements not read from text file.
- Update README.md
- Merge and resolving conflicts in README
- Update and rename eslintrc.js to .eslintrc
- Add ESLint conf file
- Update README.md
- Update .travis.yml
- Create requirements-test.txt
- Update requirements.txt
- Update setup.py
- Update README.md
- Update README.md
- Create .travis.yml
- Update README.md
- Improve formating
- Brief readme
- Change licence url
- Add first version draft
- Initial commit


